@@ -33,6 +33,7 @@ use Composer\Util\Platform;
 use Composer\Script\ScriptEvents;
 use Composer\Util\PackageSorter;
 use Composer\Json\JsonFile;
+use Composer\Package\Locker;
 
 /**
  * @author Igor Wiedler <igor@wiedler.ch>
@@ -70,6 +71,11 @@ class AutoloadGenerator
      */
     private $apcuPrefix;
 
+    /**
+     * @var bool
+     */
+    private $dryRun = false;
+
     /**
      * @var bool
      */
@@ -114,7 +120,7 @@ class AutoloadGenerator
     public function setApcu(bool $apcu, ?string $apcuPrefix = null)
     {
         $this->apcu = $apcu;
-        $this->apcuPrefix = $apcuPrefix !== null ? $apcuPrefix : $apcuPrefix;
+        $this->apcuPrefix = $apcuPrefix;
     }
 
     /**
@@ -127,6 +133,14 @@ class AutoloadGenerator
         $this->runScripts = $runScripts;
     }
 
+    /**
+     * Whether to run in drymode or not
+     */
+    public function setDryRun(bool $dryRun = true): void
+    {
+        $this->dryRun = $dryRun;
+    }
+
     /**
      * Whether platform requirements should be ignored.
      *
@@ -159,7 +173,7 @@ class AutoloadGenerator
      * @throws \Seld\JsonLint\ParsingException
      * @throws \RuntimeException
      */
-    public function dump(Config $config, InstalledRepositoryInterface $localRepo, RootPackageInterface $rootPackage, InstallationManager $installationManager, string $targetDir, bool $scanPsrPackages = false, ?string $suffix = null)
+    public function dump(Config $config, InstalledRepositoryInterface $localRepo, RootPackageInterface $rootPackage, InstallationManager $installationManager, string $targetDir, bool $scanPsrPackages = false, ?string $suffix = null, ?Locker $locker = null)
     {
         if ($this->classMapAuthoritative) {
             // Force scanPsrPackages when classmap is authoritative
@@ -392,12 +406,15 @@ EOF;
                 }
             }
 
-            // generate one if we still haven't got a suffix
             if (null === $suffix) {
-                $suffix = md5(uniqid('', true));
+                $suffix = $locker !== null && $locker->isLocked() ? $locker->getLockData()['content-hash'] : md5(uniqid('', true));
             }
         }
 
+        if ($this->dryRun) {
+            return $classMap;
+        }
+
         $filesystem->filePutContentsIfModified($targetDir.'/autoload_namespaces.php', $namespacesFile);
         $filesystem->filePutContentsIfModified($targetDir.'/autoload_psr4.php', $psr4File);
         $filesystem->filePutContentsIfModified($targetDir.'/autoload_classmap.php', $classmapFile);
@@ -473,7 +490,7 @@ EOF;
 
     /**
      * @param PackageInterface[] $packages
-     * @return array<int, array{0: PackageInterface, 1: string}>
+     * @return non-empty-array<int, array{0: PackageInterface, 1: string|null}>
      */
     public function buildPackageMap(InstallationManager $installationManager, PackageInterface $rootPackage, array $packages)
     {
@@ -485,7 +502,6 @@ EOF;
                 continue;
             }
             $this->validatePackage($package);
-
             $packageMap[] = [
                 $package,
                 $installationManager->getInstallPath($package),
@@ -519,7 +535,7 @@ EOF;
     /**
      * Compiles an ordered list of namespace => path mappings
      *
-     * @param array<int, array{0: PackageInterface, 1: string}> $packageMap array of array(package, installDir-relative-to-composer.json)
+     * @param non-empty-array<int, array{0: PackageInterface, 1: string|null}> $packageMap array of array(package, installDir-relative-to-composer.json or null for metapackages)
      * @param RootPackageInterface $rootPackage root package instance
      * @param bool|string[] $filteredDevPackages If an array, the list of packages that must be removed. If bool, whether to filter out require-dev packages
      * @return array
@@ -609,7 +625,7 @@ EOF;
     }
 
     /**
-     * @param array<int, array{0: PackageInterface, 1: string}> $packageMap
+     * @param array<int, array{0: PackageInterface, 1: string|null}> $packageMap
      * @return ?string
      */
     protected function getIncludePathsFile(array $packageMap, Filesystem $filesystem, string $basePath, string $vendorPath, string $vendorPathCode, string $appBaseDirCode)
@@ -619,6 +635,11 @@ EOF;
         foreach ($packageMap as $item) {
             [$package, $installPath] = $item;
 
+            // packages that are not installed cannot autoload anything
+            if (null === $installPath) {
+                continue;
+            }
+
             if (null !== $package->getTargetDir() && strlen($package->getTargetDir()) > 0) {
                 $installPath = substr($installPath, 0, -strlen('/'.$package->getTargetDir()));
             }
@@ -658,10 +679,26 @@ EOF;
      */
     protected function getIncludeFilesFile(array $files, Filesystem $filesystem, string $basePath, string $vendorPath, string $vendorPathCode, string $appBaseDirCode)
     {
+        // Get the path to each file, and make sure these paths are unique.
+        $files = array_map(
+            function (string $functionFile) use ($filesystem, $basePath, $vendorPath): string {
+                return $this->getPathCode($filesystem, $basePath, $vendorPath, $functionFile);
+            },
+            $files
+        );
+        $uniqueFiles = array_unique($files);
+        if (count($uniqueFiles) < count($files)) {
+            $this->io->writeError('<warning>The following "files" autoload rules are included multiple times, this may cause issues and should be resolved:</warning>');
+            foreach (array_unique(array_diff_assoc($files, $uniqueFiles)) as $duplicateFile) {
+                $this->io->writeError('<warning> - '.$duplicateFile.'</warning>');
+            }
+        }
+        unset($uniqueFiles);
+
         $filesCode = '';
+
         foreach ($files as $fileIdentifier => $functionFile) {
-            $filesCode .= '    ' . var_export($fileIdentifier, true) . ' => '
-                . $this->getPathCode($filesystem, $basePath, $vendorPath, $functionFile) . ",\n";
+            $filesCode .= '    ' . var_export($fileIdentifier, true) . ' => ' . $functionFile . ",\n";
         }
 
         if (!$filesCode) {
@@ -712,7 +749,7 @@ EOF;
     }
 
     /**
-     * @param array<int, array{0: PackageInterface, 1: string}> $packageMap
+     * @param array<int, array{0: PackageInterface, 1: string|null}> $packageMap
      * @param bool|'php-only' $checkPlatform
      * @param string[] $devPackageNames
      * @return ?string
@@ -720,6 +757,7 @@ EOF;
     protected function getPlatformCheck(array $packageMap, $checkPlatform, array $devPackageNames)
     {
         $lowestPhpVersion = Bound::zero();
+        $requiredPhp64bit = false;
         $requiredExtensions = [];
         $extensionProviders = [];
 
@@ -744,13 +782,17 @@ EOF;
                     continue;
                 }
 
-                if ('php' === $link->getTarget()) {
+                if (in_array($link->getTarget(), ['php', 'php-64bit'], true)) {
                     $constraint = $link->getConstraint();
                     if ($constraint->getLowerBound()->compareTo($lowestPhpVersion, '>')) {
                         $lowestPhpVersion = $constraint->getLowerBound();
                     }
                 }
 
+                if ('php-64bit' === $link->getTarget()) {
+                    $requiredPhp64bit = true;
+                }
+
                 if ($checkPlatform === true && Preg::isMatch('{^ext-(.+)$}iD', $link->getTarget(), $match)) {
                     // skip extension checks if they have a valid provider/replacer
                     if (isset($extensionProviders[$match[1]])) {
@@ -823,6 +865,16 @@ if (!($requiredPhp)) {
     \$issues[] = 'Your Composer dependencies require a PHP version $requiredPhpError. You are running ' . PHP_VERSION . '.';
 }
 
+PHP_CHECK;
+        }
+
+        if ($requiredPhp64bit) {
+            $requiredPhp .= <<<PHP_CHECK
+
+if (PHP_INT_SIZE !== 8) {
+    \$issues[] = 'Your Composer dependencies require a 64-bit build of PHP.';
+}
+
 PHP_CHECK;
         }
 
@@ -1081,6 +1133,10 @@ HEADER;
             $loader->setPsr4($namespace, $path);
         }
 
+        /**
+         * @var string $vendorDir
+         * @var string $baseDir
+         */
         $classMap = require $targetDir . '/autoload_classmap.php';
         if ($classMap) {
             $loader->addClassMap($classMap);
@@ -1145,7 +1201,7 @@ INITIALIZER;
     }
 
     /**
-     * @param array<int, array{0: PackageInterface, 1: string}> $packageMap
+     * @param array<int, array{0: PackageInterface, 1: string|null}> $packageMap
      * @param string $type one of: 'psr-0'|'psr-4'|'classmap'|'files'
      * @return array<int, string>|array<string, array<string>>|array<string, string>
      */
@@ -1156,6 +1212,11 @@ INITIALIZER;
         foreach ($packageMap as $item) {
             [$package, $installPath] = $item;
 
+            // packages that are not installed cannot autoload anything
+            if (null === $installPath) {
+                continue;
+            }
+
             $autoload = $package->getAutoload();
             if ($this->devMode && $package === $rootPackage) {
                 $autoload = array_merge_recursive($autoload, $package->getDevAutoload());
@@ -1245,10 +1306,8 @@ INITIALIZER;
     /**
      * Filters out dev-dependencies
      *
-     * @param array<int, array{0: PackageInterface, 1: string}> $packageMap
-     * @return array<int, array{0: PackageInterface, 1: string}>
-     *
-     * @phpstan-param array<int, array{0: PackageInterface, 1: string}> $packageMap
+     * @param array<int, array{0: PackageInterface, 1: string|null}> $packageMap
+     * @return array<int, array{0: PackageInterface, 1: string|null}>
      */
     protected function filterPackageMap(array $packageMap, RootPackageInterface $rootPackage)
     {
@@ -1301,8 +1360,8 @@ INITIALIZER;
      *
      * Packages of equal weight are sorted alphabetically
      *
-     * @param array<int, array{0: PackageInterface, 1: string}> $packageMap
-     * @return array<int, array{0: PackageInterface, 1: string}>
+     * @param array<int, array{0: PackageInterface, 1: string|null}> $packageMap
+     * @return array<int, array{0: PackageInterface, 1: string|null}>
      */
     protected function sortPackageMap(array $packageMap)
     {
