@@ -15,6 +15,7 @@ namespace Composer\DependencyResolver;
 use Composer\Package\AliasPackage;
 use Composer\Package\BasePackage;
 use Composer\Package\PackageInterface;
+use Composer\Semver\CompilingMatcher;
 use Composer\Semver\Constraint\Constraint;
 
 /**
@@ -27,15 +28,21 @@ class DefaultPolicy implements PolicyInterface
     private $preferStable;
     /** @var bool */
     private $preferLowest;
+    /** @var array<string, string>|null */
+    private $preferredVersions;
     /** @var array<int, array<string, array<int, int>>> */
     private $preferredPackageResultCachePerPool;
     /** @var array<int, array<string, int>> */
     private $sortingCachePerPool;
 
-    public function __construct(bool $preferStable = false, bool $preferLowest = false)
+    /**
+     * @param array<string, string>|null $preferredVersions Must be an array of package name => normalized version
+     */
+    public function __construct(bool $preferStable = false, bool $preferLowest = false, ?array $preferredVersions = null)
     {
         $this->preferStable = $preferStable;
         $this->preferLowest = $preferLowest;
+        $this->preferredVersions = $preferredVersions;
     }
 
     /**
@@ -49,10 +56,15 @@ class DefaultPolicy implements PolicyInterface
             return BasePackage::$stabilities[$stabA] < BasePackage::$stabilities[$stabB];
         }
 
-        $constraint = new Constraint($operator, $b->getVersion());
-        $version = new Constraint('==', $a->getVersion());
+        // dev versions need to be compared as branches via matchSpecific's special treatment, the rest can be optimized with compiling matcher
+        if (strpos($a->getVersion(), 'dev-') === 0 || strpos($b->getVersion(), 'dev-') === 0) {
+            $constraint = new Constraint($operator, $b->getVersion());
+            $version = new Constraint('==', $a->getVersion());
 
-        return $constraint->matchSpecific($version, true);
+            return $constraint->matchSpecific($version, true);
+        }
+
+        return CompilingMatcher::match(new Constraint($operator, $b->getVersion()), Constraint::OP_EQ, $a->getVersion());
     }
 
     /**
@@ -198,6 +210,22 @@ class DefaultPolicy implements PolicyInterface
      */
     protected function pruneToBestVersion(Pool $pool, array $literals): array
     {
+        if ($this->preferredVersions !== null) {
+            $name = $pool->literalToPackage($literals[0])->getName();
+            if (isset($this->preferredVersions[$name])) {
+                $preferredVersion = $this->preferredVersions[$name];
+                $bestLiterals = [];
+                foreach ($literals as $literal) {
+                    if ($pool->literalToPackage($literal)->getVersion() === $preferredVersion) {
+                        $bestLiterals[] = $literal;
+                    }
+                }
+                if (\count($bestLiterals) > 0) {
+                    return $bestLiterals;
+                }
+            }
+        }
+
         $operator = $this->preferLowest ? '<' : '>';
         $bestLiterals = [$literals[0]];
         $bestPackage = $pool->literalToPackage($literals[0]);
