@@ -453,7 +453,7 @@ class Problem
     }
 
     /**
-     * @param array<string, string> $versions an array of pretty versions, with normalized versions as keys
+     * @param array<string|int, string> $versions an array of pretty versions, with normalized versions as keys
      * @return list<string> a list of pretty versions and '...' where versions were removed
      */
     private static function condenseVersionList(array $versions, int $max, int $maxDev = 16): array
@@ -465,10 +465,10 @@ class Problem
         $filtered = [];
         $byMajor = [];
         foreach ($versions as $version => $pretty) {
-            if (0 === stripos($version, 'dev-')) {
+            if (0 === stripos((string) $version, 'dev-')) {
                 $byMajor['dev'][] = $pretty;
             } else {
-                $byMajor[Preg::replace('{^(\d+)\..*}', '$1', $version)][] = $pretty;
+                $byMajor[Preg::replace('{^(\d+)\..*}', '$1', (string) $version)][] = $pretty;
             }
         }
         foreach ($byMajor as $majorVersion => $versionsForMajor) {
@@ -557,6 +557,19 @@ class Problem
      */
     protected static function constraintToText(?ConstraintInterface $constraint = null): string
     {
+        if ($constraint instanceof Constraint && $constraint->getOperator() === Constraint::STR_OP_EQ && !str_starts_with($constraint->getVersion(), 'dev-')) {
+            if (!Preg::isMatch('{^\d+(?:\.\d+)*$}', $constraint->getPrettyString())) {
+                return ' '.$constraint->getPrettyString() .' (exact version match)';
+            }
+
+            $versions = [$constraint->getPrettyString()];
+            for ($i = 3 - substr_count($versions[0], '.'); $i > 0; $i--) {
+                $versions[] = end($versions) . '.0';
+            }
+
+            return ' ' . $constraint->getPrettyString() . ' (exact version match: ' . (count($versions) > 1 ? implode(', ', array_slice($versions, 0, -1)) . ' or ' . end($versions) : $versions[0]) . ')';
+        }
+
         return $constraint ? ' '.$constraint->getPrettyString() : '';
     }
 }
