@@ -353,7 +353,7 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
 
         $this->filesystem->emptyDirectory($path);
         $this->filesystem->ensureDirectoryExists($path);
-        $this->filesystem->rename($this->getFileName($package, $path), $path . '/' . pathinfo(parse_url(strtr((string) $package->getDistUrl(), '\\', '/'), PHP_URL_PATH), PATHINFO_BASENAME));
+        $this->filesystem->rename($this->getFileName($package, $path), $path . '/' . $this->getDistPath($package, PATHINFO_BASENAME));
 
         if ($package->getBinaries()) {
             // Single files can not have a mode set like files in archives
@@ -368,6 +368,11 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
         return \React\Promise\resolve(null);
     }
 
+    protected function getDistPath(PackageInterface $package, int $component): string
+    {
+        return pathinfo((string) parse_url(strtr((string) $package->getDistUrl(), '\\', '/'), PHP_URL_PATH), $component);
+    }
+
     protected function clearLastCacheWrite(PackageInterface $package): void
     {
         if ($this->cache && isset($this->lastCacheWrites[$package->getName()])) {
@@ -431,7 +436,12 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
      */
     protected function getFileName(PackageInterface $package, string $path): string
     {
-        return rtrim($this->config->get('vendor-dir').'/composer/tmp-'.md5($package.spl_object_hash($package)).'.'.pathinfo(parse_url(strtr((string) $package->getDistUrl(), '\\', '/'), PHP_URL_PATH), PATHINFO_EXTENSION), '.');
+        $extension = $this->getDistPath($package, PATHINFO_EXTENSION);
+        if ($extension === '') {
+            $extension = $package->getDistType();
+        }
+
+        return rtrim($this->config->get('vendor-dir') . '/composer/tmp-' . md5($package . spl_object_hash($package)) . '.' . $extension, '.');
     }
 
     /**
@@ -448,7 +458,7 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
     /**
      * Process the download url
      *
-     * @param  PackageInterface  $package package the url is coming from
+     * @param  PackageInterface  $package package instance
      * @param  non-empty-string  $url     download url
      * @throws \RuntimeException If any problem with the url
      * @return non-empty-string  url
