@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -20,23 +20,23 @@ namespace Composer\Package\Archiver;
 class PharArchiver implements ArchiverInterface
 {
     /** @var array<string, int> */
-    protected static $formats = array(
+    protected static $formats = [
         'zip' => \Phar::ZIP,
         'tar' => \Phar::TAR,
         'tar.gz' => \Phar::TAR,
         'tar.bz2' => \Phar::TAR,
-    );
+    ];
 
     /** @var array<string, int> */
-    protected static $compressFormats = array(
+    protected static $compressFormats = [
         'tar.gz' => \Phar::GZ,
         'tar.bz2' => \Phar::BZ2,
-    );
+    ];
 
     /**
      * @inheritDoc
      */
-    public function archive($sources, $target, $format, array $excludes = array(), $ignoreFilters = false)
+    public function archive(string $sources, string $target, string $format, array $excludes = [], bool $ignoreFilters = false): string
     {
         $sources = realpath($sources);
 
@@ -97,7 +97,7 @@ class PharArchiver implements ArchiverInterface
     /**
      * @inheritDoc
      */
-    public function supports($format, $sourceType)
+    public function supports(string $format, ?string $sourceType): bool
     {
         return isset(static::$formats[$format]);
     }
