@@ -282,7 +282,7 @@ class ArrayLoader implements LoaderInterface
                 $package->setAuthors($config['authors']);
             }
 
-            if (isset($config['support'])) {
+            if (isset($config['support']) && \is_array($config['support'])) {
                 $package->setSupport($config['support']);
             }
 
@@ -455,7 +455,7 @@ class ArrayLoader implements LoaderInterface
         if (
             isset($config['default-branch'])
             && $config['default-branch'] === true
-            && false === $this->versionParser->parseNumericAliasPrefix($config['version'])
+            && false === $this->versionParser->parseNumericAliasPrefix(Preg::replace('{^v}', '', $config['version']))
         ) {
             return VersionParser::DEFAULT_BRANCH_ALIAS;
         }
