@@ -18,6 +18,7 @@ use Composer\Pcre\Preg;
 use Composer\Repository\InstalledRepository;
 use Composer\Repository\LockArrayRepository;
 use Composer\Repository\PlatformRepository;
+use Composer\Repository\RootPackageRepository;
 use Composer\Util\ProcessExecutor;
 use Composer\Package\Dumper\ArrayDumper;
 use Composer\Package\Loader\ArrayLoader;
@@ -473,7 +474,11 @@ class Locker
             return null;
         }
 
-        $path = realpath($this->installationManager->getInstallPath($package));
+        $path = $this->installationManager->getInstallPath($package);
+        if ($path === null) {
+            return null;
+        }
+        $path = realpath($path);
         $sourceType = $package->getSourceType();
         $datetime = null;
 
@@ -510,9 +515,10 @@ class Locker
         if ($includeDev === true) {
             $sets[] = ['repo' => $this->getLockedRepository(true), 'method' => 'getDevRequires', 'description' => 'Required (in require-dev)'];
         }
+        $rootRepo = new RootPackageRepository(clone $package);
 
         foreach ($sets as $set) {
-            $installedRepo = new InstalledRepository([$set['repo']]);
+            $installedRepo = new InstalledRepository([$set['repo'], $rootRepo]);
 
             foreach (call_user_func([$package, $set['method']]) as $link) {
                 if (PlatformRepository::isPlatformPackage($link->getTarget())) {
@@ -523,9 +529,21 @@ class Locker
                 }
                 if ($installedRepo->findPackagesWithReplacersAndProviders($link->getTarget(), $link->getConstraint()) === []) {
                     $results = $installedRepo->findPackagesWithReplacersAndProviders($link->getTarget());
+
                     if ($results !== []) {
                         $provider = reset($results);
-                        $missingRequirementInfo[] = '- ' . $set['description'].' package "' . $link->getTarget() . '" is in the lock file as "'.$provider->getPrettyVersion().'" but that does not satisfy your constraint "'.$link->getPrettyConstraint().'".';
+                        $description = $provider->getPrettyVersion();
+                        if ($provider->getName() !== $link->getTarget()) {
+                            foreach (['getReplaces' => 'replaced as %s by %s', 'getProvides' => 'provided as %s by %s'] as $method => $text) {
+                                foreach (call_user_func([$provider, $method]) as $providerLink) {
+                                    if ($providerLink->getTarget() === $link->getTarget()) {
+                                        $description = sprintf($text, $providerLink->getPrettyConstraint(), $provider->getPrettyName().' '.$provider->getPrettyVersion());
+                                        break 2;
+                                    }
+                                }
+                            }
+                        }
+                        $missingRequirementInfo[] = '- ' . $set['description'].' package "' . $link->getTarget() . '" is in the lock file as "'.$description.'" but that does not satisfy your constraint "'.$link->getPrettyConstraint().'".';
                     } else {
                         $missingRequirementInfo[] = '- ' . $set['description'].' package "' . $link->getTarget() . '" is not present in the lock file.';
                     }
