@@ -322,9 +322,8 @@ class VersionGuesser
                             $prettyVersion = 'dev-' . $candidateVersion;
                             if ($length === 0) {
                                 foreach ($promises as $promise) {
-                                    if ($promise instanceof CancellablePromiseInterface) {
-                                        $promise->cancel();
-                                    }
+                                    // to support react/promise 2.x we wrap the promise in a resolve() call for safety
+                                    \React\Promise\resolve($promise)->cancel();
                                 }
                             }
                         }
