@@ -42,7 +42,7 @@ class ArrayRepository implements RepositoryInterface
     /**
      * @param array<PackageInterface> $packages
      */
-    public function __construct(array $packages = array())
+    public function __construct(array $packages = [])
     {
         foreach ($packages as $package) {
             $this->addPackage($package);
@@ -57,12 +57,12 @@ class ArrayRepository implements RepositoryInterface
     /**
      * @inheritDoc
      */
-    public function loadPackages(array $packageNameMap, array $acceptableStabilities, array $stabilityFlags, array $alreadyLoaded = array())
+    public function loadPackages(array $packageNameMap, array $acceptableStabilities, array $stabilityFlags, array $alreadyLoaded = [])
     {
         $packages = $this->getPackages();
 
-        $result = array();
-        $namesFound = array();
+        $result = [];
+        $namesFound = [];
         foreach ($packages as $package) {
             if (array_key_exists($package->getName(), $packageNameMap)) {
                 if (
@@ -91,7 +91,7 @@ class ArrayRepository implements RepositoryInterface
             }
         }
 
-        return array('namesFound' => array_keys($namesFound), 'packages' => $result);
+        return ['namesFound' => array_keys($namesFound), 'packages' => $result];
     }
 
     /**
@@ -125,7 +125,7 @@ class ArrayRepository implements RepositoryInterface
     {
         // normalize name
         $name = strtolower($name);
-        $packages = array();
+        $packages = [];
 
         if (null !== $constraint && !$constraint instanceof ConstraintInterface) {
             $versionParser = new VersionParser();
@@ -155,11 +155,11 @@ class ArrayRepository implements RepositoryInterface
             $regex = '{(?:'.implode('|', Preg::split('{\s+}', $query)).')}i';
         }
 
-        $matches = array();
+        $matches = [];
         foreach ($this->getPackages() as $package) {
             $name = $package->getName();
             if ($mode === self::SEARCH_VENDOR) {
-                list($name) = explode('/', $name);
+                [$name] = explode('/', $name);
             }
             if (isset($matches[$name])) {
                 continue;
@@ -172,15 +172,15 @@ class ArrayRepository implements RepositoryInterface
                 || ($mode === self::SEARCH_FULLTEXT && $package instanceof CompletePackageInterface && Preg::isMatch($regex, implode(' ', (array) $package->getKeywords()) . ' ' . $package->getDescription()))
             ) {
                 if ($mode === self::SEARCH_VENDOR) {
-                    $matches[$name] = array(
+                    $matches[$name] = [
                         'name' => $name,
                         'description' => null,
-                    );
+                    ];
                 } else {
-                    $matches[$name] = array(
+                    $matches[$name] = [
                         'name' => $package->getPrettyName(),
                         'description' => $package instanceof CompletePackageInterface ? $package->getDescription() : null,
-                    );
+                    ];
 
                     if ($package instanceof CompletePackageInterface && $package->isAbandoned()) {
                         $matches[$name]['abandoned'] = $package->getReplacementPackage() ?: true;
@@ -198,7 +198,7 @@ class ArrayRepository implements RepositoryInterface
     public function hasPackage(PackageInterface $package)
     {
         if ($this->packageMap === null) {
-            $this->packageMap = array();
+            $this->packageMap = [];
             foreach ($this->getPackages() as $repoPackage) {
                 $this->packageMap[$repoPackage->getUniqueName()] = $repoPackage;
             }
@@ -239,7 +239,7 @@ class ArrayRepository implements RepositoryInterface
      */
     public function getProviders(string $packageName)
     {
-        $result = array();
+        $result = [];
 
         foreach ($this->getPackages() as $candidate) {
             if (isset($result[$candidate->getName()])) {
@@ -247,11 +247,11 @@ class ArrayRepository implements RepositoryInterface
             }
             foreach ($candidate->getProvides() as $link) {
                 if ($packageName === $link->getTarget()) {
-                    $result[$candidate->getName()] = array(
+                    $result[$candidate->getName()] = [
                         'name' => $candidate->getName(),
                         'description' => $candidate instanceof CompletePackageInterface ? $candidate->getDescription() : null,
                         'type' => $candidate->getType(),
-                    );
+                    ];
                     continue 2;
                 }
             }
@@ -261,9 +261,6 @@ class ArrayRepository implements RepositoryInterface
     }
 
     /**
-     * @param string $alias
-     * @param string $prettyAlias
-     *
      * @return AliasPackage|CompleteAliasPackage
      */
     protected function createAliasPackage(BasePackage $package, string $alias, string $prettyAlias)
@@ -339,6 +336,6 @@ class ArrayRepository implements RepositoryInterface
      */
     protected function initialize()
     {
-        $this->packages = array();
+        $this->packages = [];
     }
 }
