@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -19,16 +19,11 @@ use Composer\Pcre\Preg;
  */
 class Keys
 {
-    /**
-     * @param string $path
-     *
-     * @return string
-     */
-    public static function fingerprint($path)
+    public static function fingerprint(string $path): string
     {
         $hash = strtoupper(hash('sha256', Preg::replace('{\s}', '', file_get_contents($path))));
 
-        return implode(' ', array(
+        return implode(' ', [
             substr($hash, 0, 8),
             substr($hash, 8, 8),
             substr($hash, 16, 8),
@@ -38,6 +33,6 @@ class Keys
             substr($hash, 40, 8),
             substr($hash, 48, 8),
             substr($hash, 56, 8),
-        ));
+        ]);
     }
 }
