@@ -126,7 +126,7 @@ class PoolBuilderTest extends TestCase
             if (isset($requestData['allowTransitiveDeps']) && $requestData['allowTransitiveDeps']) {
                 $transitiveDeps = Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS;
             }
-            $request->setUpdateAllowList(array_flip($requestData['allowList']), $transitiveDeps);
+            $request->setUpdateAllowList($requestData['allowList'], $transitiveDeps);
         }
 
         foreach ($fixed as $fixedPackage) {
@@ -137,10 +137,14 @@ class PoolBuilderTest extends TestCase
 
         $result = $this->getPackageResultSet($pool, $packageIds);
 
+        sort($expect);
+        sort($result);
         $this->assertSame($expect, $result, 'Unoptimized pool does not match expected package set');
 
         $optimizer = new PoolOptimizer(new DefaultPolicy());
         $result = $this->getPackageResultSet($optimizer->optimize($request, $pool), $packageIds);
+        sort($expectOptimized);
+        sort($result);
         $this->assertSame($expectOptimized, $result, 'Optimized pool does not match expected package set');
 
         chdir($oldCwd);
