@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -19,7 +19,7 @@ class FactoryTest extends TestCase
     /**
      * @group TLS
      */
-    public function testDefaultValuesAreAsExpected()
+    public function testDefaultValuesAreAsExpected(): void
     {
         $ioMock = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
 
