@@ -426,6 +426,12 @@ class ValidatingArrayLoaderTest extends TestCase
                 ],
                 ['replace.0 : invalid version constraint (Could not parse version constraint acme/bar: Invalid version string "acme/bar")'],
             ],
+            [
+                [
+                    'require' => ['acme/bar' => '^1.0']
+                ],
+                ['name : must be present'],
+            ]
         ]);
     }
 
@@ -480,6 +486,20 @@ class ValidatingArrayLoaderTest extends TestCase
                 ],
                 false,
             ],
+            [
+                [
+                    'name' => 'foo/bar',
+                    'require' => [
+                        'foo/baz' => '>1, <0.5',
+                        'bar/baz' => 'dev-main, >0.5',
+                    ],
+                ],
+                [
+                    'require.foo/baz : this version constraint cannot possibly match anything (>1, <0.5)',
+                    'require.bar/baz : this version constraint cannot possibly match anything (dev-main, >0.5)',
+                ],
+                false,
+            ],
             [
                 [
                     'name' => 'foo/bar',
