@@ -55,7 +55,7 @@ class HgDriverTest extends TestCase
         );
     }
 
-    public function supportsDataProvider(): array
+    public static function supportsDataProvider(): array
     {
         return [
             ['ssh://bitbucket.org/user/repo'],
