@@ -27,6 +27,11 @@ if (!class_exists(InstalledVersions::class, false)) {
 
 Platform::putEnv('COMPOSER_TESTS_ARE_RUNNING', '1');
 
+// ensure Windows color support detection does not attempt to use colors
+// as this is dependent on env vars and not actual stream capabilities, see
+// https://github.com/composer/composer/issues/11598
+Platform::putEnv('NO_COLOR', '1');
+
 // symfony/phpunit-bridge sets some default env vars which we do not need polluting the test env
 Platform::clearEnv('COMPOSER');
 Platform::clearEnv('COMPOSER_VENDOR_DIR');
